@@ -1,10 +1,10 @@
-//$Id: kmag.cpp,v 1.33 2003/02/02 21:05:51 mlaurent Exp $
+//$Id: kmag.cpp,v 1.37 2003/03/15 05:58:21 sarang Exp $
 /***************************************************************************
                           kmag.cpp  -  description
                              -------------------
     begin                : Mon Feb 12 23:45:41 EST 2001
     copyright            : (C) 2001-2003 by Sarang Lakare
-    email                : sarang@users.sourceforge.net
+    email                : sarang#users.sourceforge.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -71,42 +71,42 @@
 #define ID_STATUS_MSG 1
 
 KmagApp::KmagApp(QWidget* , const char* name)
-	: KMainWindow(0, name, WStyle_MinMax | WType_TopLevel | WDestructiveClose | WStyle_ContextHelp | WStyle_StaysOnTop),
+  : KMainWindow(0, name, WStyle_MinMax | WType_TopLevel | WDestructiveClose | WStyle_ContextHelp | WStyle_StaysOnTop),
     m_defaultMouseCursorType(2)
 {
   config=kapp->config();
 
-	zoomArrayString << "5:1" << "2:1" << "1:1" << "1:1.5" << "1:2" << "1:3" << "1:4" << "1:5"
-		<< "1:6" << "1:7" << "1:8" << "1:12" << "1:16" << "1:20";
+  zoomArrayString << "5:1" << "2:1" << "1:1" << "1:1.5" << "1:2" << "1:3" << "1:4" << "1:5"
+    << "1:6" << "1:7" << "1:8" << "1:12" << "1:16" << "1:20";
 
-	// Is there a better way to initialize a vector array?
-	zoomArray.push_back(0.2); zoomArray.push_back(0.5); zoomArray.push_back(1.0);
-	zoomArray.push_back(1.5); zoomArray.push_back(2.0); zoomArray.push_back(3.0);
-	zoomArray.push_back(4.0); zoomArray.push_back(5.0); zoomArray.push_back(6.0); zoomArray.push_back(7.0);
-	zoomArray.push_back(8.0); zoomArray.push_back(12.0); zoomArray.push_back(16.0); zoomArray.push_back(20.0);
+  // Is there a better way to initialize a vector array?
+  zoomArray.push_back(0.2); zoomArray.push_back(0.5); zoomArray.push_back(1.0);
+  zoomArray.push_back(1.5); zoomArray.push_back(2.0); zoomArray.push_back(3.0);
+  zoomArray.push_back(4.0); zoomArray.push_back(5.0); zoomArray.push_back(6.0); zoomArray.push_back(7.0);
+  zoomArray.push_back(8.0); zoomArray.push_back(12.0); zoomArray.push_back(16.0); zoomArray.push_back(20.0);
 
-	fpsArrayString << "Very Low" << "Low" << "Medium" << "High" << "Very High";
+  fpsArrayString << i18n("Very Low") << i18n("Low") << i18n("Medium") << i18n("High") << i18n("Very High");
 
-	fpsArray.push_back(2); // very low
-	fpsArray.push_back(6); // low
-	fpsArray.push_back(10); // medium
-	fpsArray.push_back(15); // high
-	fpsArray.push_back(25); // very high
+  fpsArray.push_back(2); // very low
+  fpsArray.push_back(6); // low
+  fpsArray.push_back(10); // medium
+  fpsArray.push_back(15); // high
+  fpsArray.push_back(25); // very high
 
-	if(zoomArrayString.count() != zoomArray.size() || fpsArrayString.count() != fpsArray.size()) {
-		kdWarning() << "Check the zoom or fps array in the constructor." << endl;
-		exit(1);
-	}
+  if(zoomArrayString.count() != zoomArray.size() || fpsArrayString.count() != fpsArray.size()) {
+    kdWarning() << "Check the zoom or fps array in the constructor." << endl;
+    exit(1);
+  }
 
   // call inits to invoke all other construction parts
   initView();
   initActions();
-	initConnections();
+  initConnections();
 
   // read options from config file
   readOptions();
 
-	// Register all KIO image formats - to be used when saving image.
+  // Register all KIO image formats - to be used when saving image.
   KImageIO::registerFormats();
 }
 
@@ -115,94 +115,94 @@ KmagApp::KmagApp(QWidget* , const char* name)
  */
 KmagApp::~KmagApp()
 {
-
+    m_zoomView->showSelRect(false);
 }
 
 void KmagApp::initActions()
 {
   fileNewWindow = new KAction(i18n("New &Window"), "window_new", KStdAccel::key(KStdAccel::New), this,
-															SLOT(slotFileNewWindow()), actionCollection(),"new_window");
+                              SLOT(slotFileNewWindow()), actionCollection(),"new_window");
   fileNewWindow->setToolTip(i18n("Open a new KMagnifier window"));
 
-	refreshSwitch = new KAction(i18n("Stop"), "stop", KStdAccel::key(KStdAccel::Reload), this,
-															SLOT(slotToggleRefresh()), actionCollection(), "start_stop_refresh");
+  refreshSwitch = new KAction(i18n("Stop"), "stop", KStdAccel::key(KStdAccel::Reload), this,
+                              SLOT(slotToggleRefresh()), actionCollection(), "start_stop_refresh");
   refreshSwitch->setToolTip(i18n("Click to stop window refresh"));
   refreshSwitch->setWhatsThis(i18n("Clicking on this icon will <b>start</b> / <b>stop</b>\
   updating of the display. Stopping the update will zero the processing power\
   required (CPU usage)"));
 
   m_pSnapshot = new KAction(i18n("&Snapshot"), "ksnapshot", KStdAccel::key(KStdAccel::Save), this,
-														SLOT(saveZoomPixmap()), actionCollection(),"snapshot");
-	m_pSnapshot->setWhatsThis(i18n("Click to save the zoomed view to an image file."));
-	m_pSnapshot->setToolTip(i18n("Save image to a file"));
+                            SLOT(saveZoomPixmap()), actionCollection(),"snapshot");
+  m_pSnapshot->setWhatsThis(i18n("Click to save the zoomed view to an image file."));
+  m_pSnapshot->setToolTip(i18n("Save image to a file"));
 
   m_pPrint = KStdAction::print(this, SLOT(slotFilePrint()), actionCollection(), "print");
   m_pPrint->setWhatsThis(i18n("Click on this button to print the current zoomed view."));
 
   m_pCopy = KStdAction::copy(this, SLOT(copyToClipBoard()), actionCollection(), "copy");
   m_pCopy->setWhatsThis(i18n("Click on this button to copy the current zoomed view to the clipboard which you can paste in other applications."));
-	m_pCopy->setToolTip(i18n("Copy zoomed image to clipboard"));
+  m_pCopy->setToolTip(i18n("Copy zoomed image to clipboard"));
 
   m_fitToWindow = new KAction(i18n("&Fit Window"), "window_fullscreen", CTRL+Key_F, m_zoomView,
-															SLOT(fitToWindow()), actionCollection(),"fit_to_window");
+                              SLOT(fitToWindow()), actionCollection(),"fit_to_window");
   m_fitToWindow->setWhatsThis(i18n("Click on this button to fit the zoom view to the zoom window."));
-	m_fitToWindow->setToolTip(i18n("Maximize the use of the window"));
+  m_fitToWindow->setToolTip(i18n("Maximize the use of the window"));
 
   m_pZoomIn = KStdAction::zoomIn(this, SLOT(zoomIn()), actionCollection(), "zoom_in");
   m_pZoomIn->setWhatsThis(i18n("Click on this button to <b>zoom-in</b> on the selected region."));
 
   m_pZoomBox = new KSelectAction(i18n("&Zoom"),0,actionCollection(),"zoom");
   m_pZoomBox->setItems(zoomArrayString);
-	m_pZoomBox->setWhatsThis(i18n("Select the zoom factor."));
-	m_pZoomBox->setToolTip(i18n("Zoom factor"));
+  m_pZoomBox->setWhatsThis(i18n("Select the zoom factor."));
+  m_pZoomBox->setToolTip(i18n("Zoom factor"));
 
   m_pZoomOut = KStdAction::zoomOut(this, SLOT(zoomOut()), actionCollection(), "zoom_out");
   m_pZoomOut->setWhatsThis(i18n("Click on this button to <b>zoom-out</b> on the selected region."));
 
-	// Help toolbar popup
-	KToolBarPopupAction *helpAction = new KToolBarPopupAction(i18n("&Help"), "help",
-																					Key_F1, actionCollection(), "help_menu");
+  // Help toolbar popup
+  KToolBarPopupAction *helpAction = new KToolBarPopupAction(i18n("&Help"), "help",
+                                          Key_F1, actionCollection(), "help_menu");
 
-	KHelpMenu *newHelpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData());
+  KHelpMenu *newHelpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData());
 
-	helpAction->setDelayed(false);
-	KAction *action = KStdAction::helpContents(newHelpMenu, SLOT(appHelpActivated()), 0);
+  helpAction->setDelayed(false);
+  KAction *action = KStdAction::helpContents(newHelpMenu, SLOT(appHelpActivated()), 0);
   action->plug((QWidget*)helpAction->popupMenu());
 
-	action = KStdAction::reportBug(newHelpMenu, SLOT(reportBug()), 0);
+  action = KStdAction::reportBug(newHelpMenu, SLOT(reportBug()), 0);
   action->plug((QWidget*)helpAction->popupMenu());
 
-	action = KStdAction::aboutApp(newHelpMenu, SLOT(aboutApplication()), 0);
+  action = KStdAction::aboutApp(newHelpMenu, SLOT(aboutApplication()), 0);
   action->plug((QWidget*)helpAction->popupMenu());
 
-	action = KStdAction::aboutKDE(newHelpMenu, SLOT(aboutKDE()), 0);
+  action = KStdAction::aboutKDE(newHelpMenu, SLOT(aboutKDE()), 0);
   action->plug((QWidget*)helpAction->popupMenu());
 
-	// Settings tool bar popup
-	KToolBarPopupAction *confAction = new KToolBarPopupAction(i18n("&Settings"), "configure",
-																					0, actionCollection(), "conf_menu");
-	confAction->setDelayed(false);
-	m_keyConf = KStdAction::keyBindings( this, SLOT( slotConfKeys() ), actionCollection(), "key_conf");
-	m_keyConf->plug(confAction->popupMenu());
+  // Settings tool bar popup
+  KToolBarPopupAction *confAction = new KToolBarPopupAction(i18n("&Settings"), "configure",
+                                          0, actionCollection(), "conf_menu");
+  confAction->setDelayed(false);
+  m_keyConf = KStdAction::keyBindings( this, SLOT( slotConfKeys() ), actionCollection(), "key_conf");
+  m_keyConf->plug(confAction->popupMenu());
 
-	KAction *tbConf = KStdAction::configureToolbars( this, SLOT( slotEditToolbars() ),
-																							actionCollection(), "toolbar_conf");
-	tbConf->plug(confAction->popupMenu());
+  KAction *tbConf = KStdAction::configureToolbars( this, SLOT( slotEditToolbars() ),
+                                              actionCollection(), "toolbar_conf");
+  tbConf->plug(confAction->popupMenu());
 
   m_pFPSBox = new KSelectAction(i18n("&Refresh"),0,actionCollection(),"fps_selector");
   m_pFPSBox->setItems(fpsArrayString);
-	m_pFPSBox->setWhatsThis(i18n("Select the refresh rate. The higher the rate, the more computing power (CPU) will be needed."));
-	m_pFPSBox->setToolTip(i18n("Refresh rate"));
+  m_pFPSBox->setWhatsThis(i18n("Select the refresh rate. The higher the rate, the more computing power (CPU) will be needed."));
+  m_pFPSBox->setToolTip(i18n("Refresh rate"));
 
-	createGUI();
+  createGUI();
 
-	// we don't want a menu bar for this applications
-	menuBar()->hide();
+  // we don't want a menu bar for this applications
+  menuBar()->hide();
 }
 
 void KmagApp::initView()
 {
-	QVBox *mainView = new QVBox(this);
+  QVBox *mainView = new QVBox(this);
 
   m_zoomView = new KMagZoomView( mainView, "ZoomView" );
   m_zoomView->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)7, m_zoomView->sizePolicy().hasHeightForWidth() ) );
@@ -224,22 +224,22 @@ void KmagApp::initView()
   m_followMouseButton = new QCheckBox( m_settingsGroup, "m_followMouseButton" );
   m_followMouseButton->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, m_followMouseButton->sizePolicy().hasHeightForWidth() ) );
   m_followMouseButton->setText( i18n( "Follow mouse" ) );
-	QToolTip::add(m_followMouseButton, i18n("Magnify around the mouse cursor"));
-	QWhatsThis::add(m_followMouseButton, i18n("If selected, the area around the mouse cursor is magnified") );
+  QToolTip::add(m_followMouseButton, i18n("Magnify around the mouse cursor"));
+  QWhatsThis::add(m_followMouseButton, i18n("If selected, the area around the mouse cursor is magnified") );
   settingsGroupLayout->addWidget( m_followMouseButton );
-	connect(m_followMouseButton, SIGNAL(toggled(bool)), m_zoomView, SLOT(followMouse(bool)));
+  connect(m_followMouseButton, SIGNAL(toggled(bool)), m_zoomView, SLOT(followMouse(bool)));
 
-	m_showCursorButton = new QCheckBox( m_settingsGroup, "m_showCursorButton" );
+  m_showCursorButton = new QCheckBox( m_settingsGroup, "m_showCursorButton" );
   m_showCursorButton->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, m_followMouseButton->sizePolicy().hasHeightForWidth() ) );
   m_showCursorButton->setText( i18n( "Mouse cursor" ) );
-	QToolTip::add(m_showCursorButton, i18n("Show mouse cursor"));
+  QToolTip::add(m_showCursorButton, i18n("Show mouse cursor"));
   settingsGroupLayout->addWidget( m_showCursorButton );
-	connect(m_showCursorButton, SIGNAL(toggled(bool)), this, SLOT(showMouseCursor(bool)));
+  connect(m_showCursorButton, SIGNAL(toggled(bool)), this, SLOT(showMouseCursor(bool)));
 
   m_showSelRectButton = new QCheckBox( m_settingsGroup, "m_showSelRectButton" );
   m_showSelRectButton->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, m_showSelRectButton->sizePolicy().hasHeightForWidth() ) );
   m_showSelRectButton->setText( i18n( "Selection window" ) );
-	QToolTip::add(m_showSelRectButton, i18n("Show the selection window on the screen"));
+  QToolTip::add(m_showSelRectButton, i18n("Show the selection window on the screen"));
   settingsGroupLayout->addWidget( m_showSelRectButton );
   connect(m_showSelRectButton, SIGNAL(toggled(bool)), m_zoomView, SLOT(showSelRect(bool)));
 
@@ -251,17 +251,17 @@ void KmagApp::initView()
  */
 void KmagApp::initConnections()
 {
-	// change in zoom value -> update the view
-	connect(this, SIGNAL(updateZoomValue(float)), m_zoomView, SLOT(setZoom(float)));
-	connect(this, SIGNAL(updateFPSValue(float)), m_zoomView, SLOT(setRefreshRate(float)));
+  // change in zoom value -> update the view
+  connect(this, SIGNAL(updateZoomValue(float)), m_zoomView, SLOT(setZoom(float)));
+  connect(this, SIGNAL(updateFPSValue(float)), m_zoomView, SLOT(setRefreshRate(float)));
 
-	// change in zoom index -> update the selector
-	connect(this, SIGNAL(updateZoomIndex(int)), m_pZoomBox, SLOT(setCurrentItem(int)));
-	connect(this, SIGNAL(updateFPSIndex(int)), m_pFPSBox, SLOT(setCurrentItem(int)));
+  // change in zoom index -> update the selector
+  connect(this, SIGNAL(updateZoomIndex(int)), m_pZoomBox, SLOT(setCurrentItem(int)));
+  connect(this, SIGNAL(updateFPSIndex(int)), m_pFPSBox, SLOT(setCurrentItem(int)));
 
-	// selector selects a zoom index -> set the zoom index
-	connect(m_pZoomBox, SIGNAL(activated(int)), this, SLOT(setZoomIndex(int)));
-	connect(m_pFPSBox, SIGNAL(activated(int)), this, SLOT(setFPSIndex(int)));
+  // selector selects a zoom index -> set the zoom index
+  connect(m_pZoomBox, SIGNAL(activated(int)), this, SLOT(setZoomIndex(int)));
+  connect(m_pFPSBox, SIGNAL(activated(int)), this, SLOT(setFPSIndex(int)));
 }
 
 /**
@@ -271,12 +271,12 @@ void KmagApp::saveOptions()
 {
   config->setGroup("General Options");
   config->writeEntry("Geometry", size());
-	config->writeEntry("ZoomIndex", m_zoomIndex);
-	config->writeEntry("FPSIndex", m_fpsIndex);
-	config->writeEntry("FollowMouse", m_zoomView->getFollowMouse());
-	config->writeEntry("SelRect", m_zoomView->getSelRectPos());
-	config->writeEntry("ShowSelRect", m_zoomView->getShowSelRect());
-	config->writeEntry("ShowMouse", m_zoomView->getShowMouseType());
+  config->writeEntry("ZoomIndex", m_zoomIndex);
+  config->writeEntry("FPSIndex", m_fpsIndex);
+  config->writeEntry("FollowMouse", m_zoomView->getFollowMouse());
+  config->writeEntry("SelRect", m_zoomView->getSelRectPos());
+  config->writeEntry("ShowSelRect", m_zoomView->getShowSelRect());
+  config->writeEntry("ShowMouse", m_zoomView->getShowMouseType());
 
   toolBar("mainToolBar")->saveSettings(config,"Main ToolBar");
 }
@@ -289,44 +289,44 @@ void KmagApp::readOptions()
 {
   config->setGroup("General Options");
 
-	QSize defSize(425,390);
+  QSize defSize(425,390);
   QSize size=config->readSizeEntry("Geometry", &defSize);
   if(!size.isEmpty())
   {
     resize(size);
   }
 
-	// set zoom - defaults to 2x
-	unsigned int zoomIndex = config->readUnsignedNumEntry("ZoomIndex", 4);
-	setZoomIndex(zoomIndex);
-	emit updateZoomIndex(m_zoomIndex);
+  // set zoom - defaults to 2x
+  unsigned int zoomIndex = config->readUnsignedNumEntry("ZoomIndex", 4);
+  setZoomIndex(zoomIndex);
+  emit updateZoomIndex(m_zoomIndex);
 
-	unsigned int fpsIndex = config->readUnsignedNumEntry("FPSIndex", 2);
-	setFPSIndex(fpsIndex);
-	emit updateFPSIndex(m_fpsIndex);
+  unsigned int fpsIndex = config->readUnsignedNumEntry("FPSIndex", 2);
+  setFPSIndex(fpsIndex);
+  emit updateFPSIndex(m_fpsIndex);
 
-	bool followMouse = config->readBoolEntry("FollowMouse", true);
-	m_zoomView->followMouse(followMouse);
-	m_followMouseButton->setChecked(followMouse);
+  bool followMouse = config->readBoolEntry("FollowMouse", true);
+  m_zoomView->followMouse(followMouse);
+  m_followMouseButton->setChecked(followMouse);
 
-	QRect defaultRect(0,0,211,164);
-	m_zoomView->setSelRectPos(config->readRectEntry("SelRect", &defaultRect));
+  QRect defaultRect(0,0,211,164);
+  m_zoomView->setSelRectPos(config->readRectEntry("SelRect", &defaultRect));
 
-	bool showSelRect = config->readBoolEntry("ShowSelRect", false);
-	m_zoomView->showSelRect(showSelRect);
-	m_showSelRectButton->setChecked(showSelRect);
+  bool showSelRect = config->readBoolEntry("ShowSelRect", false);
+  m_zoomView->showSelRect(showSelRect);
+  m_showSelRectButton->setChecked(showSelRect);
 
-	m_mouseCursorType = config->readUnsignedNumEntry("ShowMouse", m_defaultMouseCursorType);
-	m_zoomView->showMouse(m_mouseCursorType);
+  m_mouseCursorType = config->readUnsignedNumEntry("ShowMouse", m_defaultMouseCursorType);
+  m_zoomView->showMouse(m_mouseCursorType);
   if(m_mouseCursorType)
     m_showCursorButton->setChecked(true);
   else
     m_showCursorButton->setChecked(false);
 
-	if(config->hasGroup("Main Toolbar"))
-	  toolBar("mainToolBar")->applySettings(config,"Main ToolBar");
+  if(config->hasGroup("Main Toolbar"))
+    toolBar("mainToolBar")->applySettings(config,"Main ToolBar");
   else
-		toolBar("mainToolBar")->setBarPos(KToolBar::Bottom);
+    toolBar("mainToolBar")->setBarPos(KToolBar::Bottom);
 }
 
 bool KmagApp::queryClose()
@@ -351,12 +351,12 @@ void KmagApp::mousePressEvent(QMouseEvent *e)
 
   switch(e->button()) {
   case QMouseEvent::RightButton :
-		// show popup
-		kdDebug() << "Show Popup now!" << endl;
-		break;
+    // show popup
+    kdDebug() << "Show Popup now!" << endl;
+    break;
   default :
     break;
-	}
+  }
 }
 
 
@@ -369,13 +369,13 @@ void KmagApp::mousePressEvent(QMouseEvent *e)
  */
 void KmagApp::showMouseCursor(bool show)
 {
-	if(show) {
+  if(show) {
     if(m_mouseCursorType == 0)
       m_mouseCursorType = m_defaultMouseCursorType;
-		m_zoomView->showMouse(m_mouseCursorType);
-	} else {
-		m_zoomView->showMouse(0);
-	}
+    m_zoomView->showMouse(m_mouseCursorType);
+  } else {
+    m_zoomView->showMouse(0);
+  }
 }
 
 /**
@@ -383,10 +383,10 @@ void KmagApp::showMouseCursor(bool show)
  */
 void KmagApp::zoomIn()
 {
-	// set the new index .. checking will done inside setZoom
-	setZoomIndex(m_zoomIndex+1);
-	// signal change in zoom index
-	emit updateZoomIndex((int)m_zoomIndex);
+  // set the new index .. checking will done inside setZoom
+  setZoomIndex(m_zoomIndex+1);
+  // signal change in zoom index
+  emit updateZoomIndex((int)m_zoomIndex);
 }
 
 /**
@@ -394,45 +394,45 @@ void KmagApp::zoomIn()
  */
 void KmagApp::zoomOut()
 {
-	// set the new index .. checking will done inside setZoom
-	setZoomIndex(m_zoomIndex-1);
-	// signal change in zoom index
-	emit updateZoomIndex((int)m_zoomIndex);
+  // set the new index .. checking will done inside setZoom
+  setZoomIndex(m_zoomIndex-1);
+  // signal change in zoom index
+  emit updateZoomIndex((int)m_zoomIndex);
 }
 /**
  * Sets the zoom index to index
  */
 void KmagApp::setZoomIndex(int index)
 {
-	if(index < 0 || index >= (int)zoomArray.size()) {
-		// the index is invalid
-		kdWarning() << "Invalid index!" << endl;
-		return;
+  if(index < 0 || index >= (int)zoomArray.size()) {
+    // the index is invalid
+    kdWarning() << "Invalid index!" << endl;
+    return;
   } else if((int)m_zoomIndex == index) {
-		// do nothing!
-		return;
-	} else {
-		m_zoomIndex = index;
-	}
+    // do nothing!
+    return;
+  } else {
+    m_zoomIndex = index;
+  }
 
   if(m_zoomIndex == 0) {
     // meaning that no more zooming-out is possible
     // -> disable zoom-out icon
     m_pZoomOut->setEnabled(false);
   } else { // enable the icon
-		m_pZoomOut->setEnabled(true);
-	}
+    m_pZoomOut->setEnabled(true);
+  }
 
   if(m_zoomIndex == zoomArray.size()-1) {
     // meaning that no more zooming-in is possible
     // -> disable zoom-in icon
     m_pZoomIn->setEnabled(false);
   } else { // enable the icon
-		m_pZoomIn->setEnabled(true);
-	}
+    m_pZoomIn->setEnabled(true);
+  }
 
-	// signal change in zoom value
-	emit updateZoomValue(zoomArray[m_zoomIndex]);
+  // signal change in zoom value
+  emit updateZoomValue(zoomArray[m_zoomIndex]);
 }
 
 /**
@@ -440,19 +440,19 @@ void KmagApp::setZoomIndex(int index)
  */
 void KmagApp::setFPSIndex(int index)
 {
-	if(index < 0 || index >= (int)fpsArray.size()) {
-		// the index is invalid
-		kdWarning() << "Invalid index!" << endl;
-		return;
+  if(index < 0 || index >= (int)fpsArray.size()) {
+    // the index is invalid
+    kdWarning() << "Invalid index!" << endl;
+    return;
   } else if((int)m_fpsIndex == index) {
-		// do nothing!
-		return;
-	} else {
-		m_fpsIndex = index;
-	}
+    // do nothing!
+    return;
+  } else {
+    m_fpsIndex = index;
+  }
 
-	// signal change in zoom value
-	emit updateFPSValue(fpsArray[m_fpsIndex]);
+  // signal change in zoom value
+  emit updateFPSValue(fpsArray[m_fpsIndex]);
 }
 
 
@@ -461,50 +461,50 @@ void KmagApp::setFPSIndex(int index)
  */
 void KmagApp::saveZoomPixmap()
 {
-	bool toggled(false);
+  bool toggled(false);
 
-	// stop refresh temporarily
+  // stop refresh temporarily
   if (m_zoomView->getRefreshStatus()) {
     slotToggleRefresh();
-		toggled = true;
+    toggled = true;
   }
 
   KURL url = KFileDialog::getSaveURL(QString::null,
-							KImageIO::pattern(KImageIO::Writing),
+              KImageIO::pattern(KImageIO::Writing),
              0,i18n("Save Zoomed Region"));
 
-	if(!url.filename().isEmpty()) {
-		if(!url.isLocalFile()) {
-			// create a temp file.. save image to it.. copy over the n/w and then delete the temp file.
-			KTempFile tempFile;
-			if(!m_zoomView->getPixmap().save(tempFile.name(), KImageIO::type(url.fileName()).latin1())) {
+  if(!url.filename().isEmpty()) {
+    if(!url.isLocalFile()) {
+      // create a temp file.. save image to it.. copy over the n/w and then delete the temp file.
+      KTempFile tempFile;
+      if(!m_zoomView->getPixmap().save(tempFile.name(), KImageIO::type(url.fileName()).latin1())) {
         KMessageBox::error(0, i18n("Unable to save temporary file (before uploading to the network file you specified)."),
-													i18n("Error Writing File"));
-			} else {
-  			if(!KIO::NetAccess::upload(tempFile.name(), url)) {
-  				KMessageBox::error(0, i18n("Unable to upload file over the network."),
-  													i18n("Error Writing File"));
-  			} else {
-					KMessageBox::information(0, i18n("Current zoomed image saved to\n")+url.prettyURL(),
-															i18n("Information"), "save_confirm");
-				}
-			}
-			// remove the temporary file
-			tempFile.unlink();
+                          i18n("Error Writing File"));
+      } else {
+        if(!KIO::NetAccess::upload(tempFile.name(), url)) {
+          KMessageBox::error(0, i18n("Unable to upload file over the network."),
+                            i18n("Error Writing File"));
+        } else {
+          KMessageBox::information(0, i18n("Current zoomed image saved to\n")+url.prettyURL(),
+                              i18n("Information"), "save_confirm");
+        }
+      }
+      // remove the temporary file
+      tempFile.unlink();
 
-		} else {
-  		if(!m_zoomView->getPixmap().save(url.path(), KImageIO::type(url.fileName()).latin1())) {
-      	KMessageBox::error(0, i18n("Unable to save file. Please check if you have permission to write to the directory."),
-  													i18n("Error Writing File"));
-  		} else {
-  			KMessageBox::information(0, i18n("Current zoomed image saved to\n")+url.prettyURL(),
-  															i18n("Information"), "save_confirm");
-  		}
-		}
-	}
-	if(toggled) {
-		slotToggleRefresh();
-	}
+    } else {
+      if(!m_zoomView->getPixmap().save(url.path(), KImageIO::type(url.fileName()).latin1())) {
+        KMessageBox::error(0, i18n("Unable to save file. Please check if you have permission to write to the directory."),
+                            i18n("Error Writing File"));
+      } else {
+        KMessageBox::information(0, i18n("Current zoomed image saved to\n")+url.prettyURL(),
+                                i18n("Information"), "save_confirm");
+      }
+    }
+  }
+  if(toggled) {
+    slotToggleRefresh();
+  }
 }
 
 
@@ -534,7 +534,7 @@ void KmagApp::slotFilePrint()
 {
 #ifndef QT_NO_PRINTER
 
-	bool toggled(false);
+  bool toggled(false);
 
 #if KDE_VERSION < 220
   QPrinter printer;
@@ -542,44 +542,44 @@ void KmagApp::slotFilePrint()
   KPrinter printer;
 #endif
 
-	// stop refresh temporarily
+  // stop refresh temporarily
   if (m_zoomView->getRefreshStatus()) {
     slotToggleRefresh();
-		toggled = true;
+    toggled = true;
   }
 
-	const QPixmap pixmap(m_zoomView->getPixmap());
+  const QPixmap pixmap(m_zoomView->getPixmap());
 
 #if KDE_VERSION >= 220
-	// use some AI to get the best orientation
-	if(pixmap.width() > pixmap.height()) {
-		printer.setOrientation(KPrinter::Landscape);
-	} else {
-		printer.setOrientation(KPrinter::Portrait);
-	}
+  // use some AI to get the best orientation
+  if(pixmap.width() > pixmap.height()) {
+    printer.setOrientation(KPrinter::Landscape);
+  } else {
+    printer.setOrientation(KPrinter::Portrait);
+  }
 #endif
 
   if (printer.setup(this)) {
     QPainter paint;
 
-		if(!paint.begin(&printer))
-	    return;
+    if(!paint.begin(&printer))
+      return;
     // draw the pixmap
-	  paint.drawPixmap(0, 0, pixmap);
-		// end the painting
-		paint.end();
+    paint.drawPixmap(0, 0, pixmap);
+    // end the painting
+    paint.end();
   }
 
-	if(toggled) {
-		slotToggleRefresh();
-	}
+  if(toggled) {
+    slotToggleRefresh();
+  }
 #endif // QT_NO_PRINTER
 }
 
 void KmagApp::copyToClipBoard()
 {
-	QClipboard *cb=KApplication::clipboard();
-	cb->setPixmap(m_zoomView->getPixmap());
+  QClipboard *cb=KApplication::clipboard();
+  cb->setPixmap(m_zoomView->getPixmap());
 }
 
 void KmagApp::slotViewToolBar()
@@ -598,21 +598,21 @@ void KmagApp::slotViewToolBar()
 
 void KmagApp::slotConfKeys()
 {
-	KKeyDialog::configureKeys( actionCollection(), xmlFile() );
+  KKeyDialog::configureKeys( actionCollection(), xmlFile() );
 }
 
 void KmagApp::slotEditToolbars()
 {
-	saveMainWindowSettings( KGlobal::config(), "MainWindow" );
-	KEditToolbar dlg( actionCollection() );
-	connect( &dlg, SIGNAL( newToolbarConfig() ), this, SLOT( slotNewToolbarConfig() ) );
-	if ( dlg.exec() )
-		createGUI();
+  saveMainWindowSettings( KGlobal::config(), "MainWindow" );
+  KEditToolbar dlg( actionCollection() );
+  connect( &dlg, SIGNAL( newToolbarConfig() ), this, SLOT( slotNewToolbarConfig() ) );
+  if ( dlg.exec() )
+    createGUI();
 }
 
 
 void KmagApp::slotNewToolbarConfig()
 {
-	applyMainWindowSettings( KGlobal::config(), "MainWindow" );
-	createGUI();
+  applyMainWindowSettings( KGlobal::config(), "MainWindow" );
+  createGUI();
 }
